License, Credits and Other Information
======================================

Copyright and License
---------------------

.. include:: ../LICENSE.txt

Credits
-------

The authors of *unittest_expander* are: Jan Kaliszewski (zuo) and the
Contributors whose `GitHub pull requests`_ have been merged into
the code repository.

.. _GitHub pull requests: https://github.com/zuo/unittest_expander/pulls?q=is%3Apr+is%3Amerged

Also, the project owes a lot to those who `report bugs and
propose/discuss enhancements`_.

.. _report bugs and propose/discuss enhancements: https://github.com/zuo/unittest_expander/issues?q=

There were also some inspirations; see the following section to learn
about some of them...

Related Links (Historical Note)
-------------------------------

Before/when creating first versions of *unittest_expander* I (Jan)
checked out several other projects and resources related to unit test
parametrization (aka *parameterization*) in Python.

Some of them were mature and actively maintained projects, others were
just minor drafts; some depended (contrary to *unittest_expander*) on
external libraries or testing frameworks, others did not; some had
appealing, programmer-friendly interfaces, others felt more like
low-level building blocks...

Anyway, here are the links:

* https://nose.readthedocs.org/en/latest/writing_tests.html#test-generators
* https://github.com/wolever/nose-parameterized
* https://github.com/msabramo/python_unittest_parameterized_test_case
* https://github.com/txels/ddt
* https://code.google.com/p/parameterized-testcase/
* *https://bitbucket.org/lothiraldan/unittest-templates/* (link no longer alive)
* https://launchpad.net/testscenarios
* https://eli.thegreenplace.net/2011/08/02/python-unit-testing-parametrized-test-cases/
* https://gist.github.com/mfazekas/1710455
* plus -- of course! -- certain brilliant features of *pytest*:

  * https://pytest.org/latest/parametrize.html
  * https://pytest.org/latest/fixture.html

* ...as well as some interesting *nose2* plugins:

  * https://nose2.readthedocs.org/en/latest/plugins/generators.html
  * https://nose2.readthedocs.org/en/latest/params.html#nose2.tools.params

See also:

* https://github.com/python/cpython/issues/52145
* https://github.com/python/cpython/issues/56809
* https://github.com/python/cpython/commit/56517e5cb91c896024934a520d365d6e275eb1ad
